
// Include the ESP8266 WiFi library. (Works a lot like the
// Arduino WiFi library.)
#include <ESP8266WiFi.h>
// Include the SparkFun Phant library.
#include <Phant.h>
#include <SparkFunMAX31855k.h> // Using the max31855k driver
#include <SPI.h>  // Included here too due Arduino IDE; Used in above header

// Wifi Manager for webserver to configure wifi http://tzapu.com/esp8266-wifi-connection-manager-library-arduino-ide/
#include <DNSServer.h>
#include <ESP8266WebServer.h>
#include <WiFiManager.h> //https://github.com/tzapu/WiFiManager

/////////////////////
// Pin Definitions //
/////////////////////
const int CHIP_SELECT_PIN = 4; // Using standard CS line (SS)
const int LED_PIN = 5; // Thing's onboard, blue LED
const int ANALOG_PIN = A0; // The only analog pin on the Thing
const int GND = 1; // Needed for SparkFunMAX31855k probe() function?
const int VCC = 3; // Needed for SparkFunMAX31855k probe() function?
const int DIGITAL_PIN = 13; // Digital input. Ground pin 13 to reset wifi manager

// SCK & MISO are defined by Arduino/Thing. Clock is 14, SPI MISO is 12

////////////////
// Phant Keys //
////////////////
const char PhantHost[] = "data.sparkfun.com";
const char PublicKey[] = "wpvZ9pE1qbFJAjaGd3bn"; //This is the demo key. Add yours here.
const char PrivateKey[] = "wzeB1z0xWNt1YJX27xdg"; //This is the demo key. Add yours here.

/////////////////
// Post Timing //
/////////////////
boolean postSparkFun = 1;
const unsigned long postRate = 300000; //milliseconds
unsigned long lastPost = 0;

// Instantiate an instance of the SparkFunMAX31855k class
SparkFunMAX31855k probe(CHIP_SELECT_PIN, VCC, GND);


void initHardware()
{
  Serial.begin(9600);
  Serial.println("\nBeginning...");
  delay(50);  // Let IC stabilize or first readings will be garbage
  pinMode(LED_PIN, OUTPUT);
  pinMode(DIGITAL_PIN, INPUT_PULLUP);
  digitalWrite(LED_PIN, LOW);
  // Don't need to set ANALOG_PIN as input, 
  // that's all it can be.
}

int postToPhant()
{
  // LED turns on when we enter, it'll go off when we 
  // successfully post.
  digitalWrite(LED_PIN, HIGH);

  // Declare an object from the Phant library - phant
  Phant phant(PhantHost, PublicKey, PrivateKey);

  // Read the temperature in Fahrenheit
  int temperature = probe.readTempF();
  if (!isnan(temperature)) {
        if (temperature > 10000)
        {
        temperature = -99;
        }
    Serial.print("\tTemp[F]=");
    Serial.println(temperature);
  }
  
  //// Read the temperature in Fahrenheit
  //int temperatureCJT = probe.readCJT();
  //if (!isnan(temperatureCJT)) {
  //      if (temperatureCJT > 10000)
  //      {
  //      temperatureCJT = -99;
  //      }
  //  Serial.print("\tTempCJT[F]=");
  //  Serial.println(temperatureCJT);
  //}

  
  // Sensor Name
  String postedID = "kiln1";

  // Add field/value pairs defined by our stream:
  phant.add("id", postedID);
  phant.add("temperature_f", temperature);

  // Now connect to data.sparkfun.com, and post our data:
  WiFiClient client;
  const int httpPort = 80;
  if (!client.connect(PhantHost, httpPort)) 
  {
    // If we fail to connect, return 0.
    return 0;
  }
  // If we successfully connected, print our Phant post:
  client.print(phant.post());

  // Read all the lines of the reply from server and print them to Serial
  while(client.available()){
    String line = client.readStringUntil('\r');
    //Serial.print(line); // Trying to avoid using serial
  }

  // Before we exit, turn the LED off.
  digitalWrite(LED_PIN, LOW);

  return 1; // Return success
}

void configModeCallback () {
  Serial.println("Entered config mode");
  Serial.println(WiFi.softAPIP());
}

int resetWifiSettings() {
  WiFiManager wifiManager; 
  wifiManager.resetSettings();
   //set custom ip for portal
  wifiManager.setAPConfig(IPAddress(1,1,1,1), IPAddress(1,1,1,1), IPAddress(255,255,255,0));
  //first parameter is name of access point, second is the password
  wifiManager.autoConnect("KilnTempSetup", "password");
  Serial.println("connected...yeey :)");
}

void setup() 
{
  Serial.begin(9600);
  Serial.println("\nBeginning...");
  delay(50);  // Let IC stabilize or first readings will be garbage
  initHardware();
  digitalWrite(LED_PIN, HIGH);

  //Wifi Manager
  WiFiManager wifiManager; 
  //reset settings - for testing
  //wifiManager.resetSettings();

  //set callback that gets called when connecting to previous WiFi fails, and enters Access Point mode
  //wifiManager.setAPCallback(configModeCallback);
  //set custom ip for portal
  wifiManager.setAPConfig(IPAddress(1,1,1,1), IPAddress(1,1,1,1), IPAddress(255,255,255,0));
  //first parameter is name of access point, second is the password
  wifiManager.autoConnect("KilnTempSetup", "password");
  Serial.println("connected...yeey :)");
}

void loop() 
{ 
  if (postSparkFun)
  {
    if (lastPost + postRate <= millis())
    {
      if (postToPhant())
        lastPost = millis();
      else
        delay(100);    
    }
  }
  if (digitalRead(DIGITAL_PIN)==LOW)
  {
    resetWifiSettings();
  }    
}

